summaryrefslogtreecommitdiff
path: root/drivers/power/bq2419x-charger.c
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/power/bq2419x-charger.c')
-rw-r--r--drivers/power/bq2419x-charger.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/power/bq2419x-charger.c b/drivers/power/bq2419x-charger.c
index 1a6b724fd1de..bc51cb162f2d 100644
--- a/drivers/power/bq2419x-charger.c
+++ b/drivers/power/bq2419x-charger.c
@@ -241,8 +241,8 @@ static int bq2419x_init(struct bq2419x_chip *bq2419x)
val = current_to_reg(iinlim, ARRAY_SIZE(iinlim),
bq2419x->in_current_limit);
- /* Start from 500mA and then step to val */
- floor = current_to_reg(iinlim, ARRAY_SIZE(iinlim), 500);
+ /* Start from 100mA and then step to val */
+ floor = current_to_reg(iinlim, ARRAY_SIZE(iinlim), 100);
if (val < 0 || floor < 0)
return 0;